package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.guarantee.GuaranteeInfoFj;
import java.util.List;


/**
 * 反担保基础信息附件Mapper接口
 * 
 * @author boman
 * @date 2024-08-01
 */
public interface GuaranteeInfoFjMapper 
{
    /**
     * 查询反担保基础信息附件
     * 
     * @param guaranteeInfoFjId 反担保基础信息附件主键
     * @return 反担保基础信息附件
     */
    public GuaranteeInfoFj selectGuaranteeInfoFjByGuaranteeInfoFjId(Long guaranteeInfoFjId);

    /**
     * 查询反担保基础信息附件列表
     * 
     * @param guaranteeInfoFj 反担保基础信息附件
     * @return 反担保基础信息附件集合
     */
    public List<GuaranteeInfoFj> selectGuaranteeInfoFjList(GuaranteeInfoFj guaranteeInfoFj);
    public List<GuaranteeInfoFj> selectGuaranteeInfoFjByLoanApplicationId(Long loanApplicationId);

    /**
     * 新增反担保基础信息附件
     * 
     * @param guaranteeInfoFj 反担保基础信息附件
     * @return 结果
     */
    public int insertGuaranteeInfoFj(GuaranteeInfoFj guaranteeInfoFj);
    public int batchGuaranteeInfoFj(List<GuaranteeInfoFj> guaranteeInfoFj);

    /**
     * 修改反担保基础信息附件
     * 
     * @param guaranteeInfoFj 反担保基础信息附件
     * @return 结果
     */
    public int updateGuaranteeInfoFj(GuaranteeInfoFj guaranteeInfoFj);

    /**
     * 删除反担保基础信息附件
     * 
     * @param guaranteeInfoFjId 反担保基础信息附件主键
     * @return 结果
     */
    public int deleteGuaranteeInfoFjByGuaranteeInfoFjId(Long guaranteeInfoFjId);

    /**
     * 批量删除反担保基础信息附件
     * 
     * @param guaranteeInfoFjIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGuaranteeInfoFjByGuaranteeInfoFjIds(Long[] guaranteeInfoFjIds);
    public int deleteGuaranteeInfoFjByGuaranteeInfoIds(Long[] guaranteeInfoId);
}
